@echo off
rem #
rem # IBM Confidential
rem # OCO Source Materials
rem # Rational ClearQuest
rem # (C) Copyright IBM Corp. 2010,2013. All Rights Reserved.
rem #
rem # The source code for this program is not published or otherwise
rem # divested of its trade secrets, irrespective of what has been
rem # deposited with the U.S. Copyright Office.
rem #
rem # Run this batch file to copy the Eclipse plugins of the reporting driver from the shared Installation
rem # Manager directory to a target directory
rem # Usage:   
rem #	copyDriverPlugins <no arguments>   - Copies the ClearQuest driver plugins to the current directory
rem #	copyDriverPlugins <targetDirectory> - Copies the ClearQuest driver plugins to the targetDirectory   
rem #	copyDriverPlugins clean - Removes existing ClearQuest driver plugins and jar files.  When this option is used, 
rem #   	the current directory is treated as the targetDirectory. 

setlocal
:start
rem PLUGIN_PATH and EXTRACT_PROGRAM path can be changed if necessary.  Other settings should not be changed.
set PLUGIN_PATH="%CLEARQUEST_HOME%\..\..\IMShared\plugins"
set EXTRACT_PROGRAM="%RATIONAL_COMMON%\infozip\unzip"

set CQ_CORE_LIB=com.ibm.rational.clearquest.core.lib
set CQ_JDBC=com.ibm.rational.clearquest.jdbc
set CM_LIBRARY=com.ibm.rational.stp
set ODA_JDBC=com.ibm.rational.clearquest.oda.jdbc_
set ODA_JDBC_NL=com.ibm.rational.clearquest.oda.jdbc.nl1

if "clean" == "%1" goto clean

if [%1]==[] goto setdefault
set TARGET_PATH=%1
set BIRT_PATH=%~1
goto copyPlugins

:setdefault
set TARGET_PATH=.
set BIRT_PATH=%cd%
goto copyPlugins


:clean
set TARGET_PATH=.
if /i (%cd:~-3%)==(lib) goto cleanJ2EE
goto :cleanOSGi


:cleanJ2EE
@echo Removing ClearQuest Reporting Driver JAR
erase stpcmmn.jar
erase stpwvcm.jar
erase stpcq.jar
erase cqjni.jar
erase commons-httpclient-3.0.1.jar
erase com.ibm.rational.clearquest*.jar
erase remote_core.jar
erase cqjdbc.jar
erase cqodajdbc.jar

@echo Renaming axis.jar.backup back to axis.jar
@echo Renaming org.apache.xml.serializer_version.jar.backup to org.apache.xml.serializer_version.jar
rename %TARGET_PATH%\*.jar.backup *.

goto:eof

:cleanOSGi
@echo Removing ClearQuest Reporting Driver plugins

FOR /D /R %cd% %%X IN (%CQ_CORE_LIB%* %CQ_JDBC%* %CM_LIBRARY%* %CQ_JDBC%* %ODA_JDBC_NL%*) DO RD /S /Q "%%X"
del com.ibm.rational.clearquest* /Q

goto:eof

rem Get the newest version of the passed plugin, and copy to the TARGET_PATH
:copyNewest
call :getNewest %1
@echo Copying %PLUGIN_PATH%\%NEWEST_FILE%
if NOT (%NEWEST_FILE%)==() copy %PLUGIN_PATH%\%NEWEST_FILE% %TARGET_PATH%
goto:eof


:copyPlugins
rem Determine if the copy target is \WEB-INF\lib.  If so, assume BIRT deployment uses standard J2EE configuration
if /i (%BIRT_PATH:~-3%)==(lib) goto copyPluginsJ2EE
if /i (%BIRT_PATH:~-4%)==(lib/) goto copyPluginsJ2EE
if /i (%BIRT_PATH:~-4%)==(lib\) goto copyPluginsJ2EE
goto copyPluginsOSGi


:copyPluginsOSGi
@echo Copying ClearQuest Reporting Driver files to OSGi directory %BIRT_PATH%

rem Two commands below create directories for expanded plugins and copy the plugin directory contents
@echo Creating directories for expanded plugins
FOR /R %PLUGIN_PATH% /D %%i IN (%CQ_CORE_LIB%* %CQ_JDBC%* %CM_LIBRARY%* %ODA_JDBC%* %ODA_JDBC_NL%*) DO mkdir %TARGET_PATH%\%%~nxi
@echo Copying content for expanded plugins
FOR /R %PLUGIN_PATH% /D %%i IN (%CQ_CORE_LIB%* %CQ_JDBC%* %CM_LIBRARY%* %ODA_JDBC%* %ODA_JDBC_NL%*) DO xcopy "%%i\*.*" %TARGET_PATH%\"%%~nxi"  /Y /S /E /I /R

rem Command below copies the plugins that are not expanded.  Those plugins are represented as jar files
@echo Copying plugin jars
FOR /R %PLUGIN_PATH% %%i IN (%CQ_CORE_LIB%* %CQ_JDBC%* %CM_LIBRARY%* %ODA_JDBC%* %ODA_JDBC_NL%*) DO copy "%%i" %TARGET_PATH%\"%%~nxi" 
goto:eof

:copyPluginsJ2EE
@echo Copying ClearQuest Reporting Driver files to J2EE lib directory %BIRT_PATH%

rem Get the base directory for the newest version of com.ibm.rational.stp, and copy all contained jars
@echo Copying embedded JAR from com.ibm.rational.stp plugin
call :getNewest %PLUGIN_PATH%\com.ibm.rational.stp_*
copy %PLUGIN_PATH%\%NEWEST_FILE%\*.jar %TARGET_PATH%

@echo Copying cqjni.jar
copy "%CLEARQUEST_HOME%\cqjni.jar" %TARGET_PATH%

call :copyNewest %PLUGIN_PATH%\com.ibm.rational.clearquest.jdbc_*.jar
call :copyNewest %PLUGIN_PATH%\com.ibm.rational.clearquest.oda.jdbc_*.jar

@echo Extracting cqjdbc.jar
%EXTRACT_PROGRAM% "%BIRT_PATH%"\com.ibm.rational.clearquest.jdbc_*.jar cqjdbc.jar -d "%BIRT_PATH%"
@echo Extracting cqodajdbc.jar
%EXTRACT_PROGRAM% "%BIRT_PATH%"\com.ibm.rational.clearquest.oda.jdbc_*.jar cqodajdbc.jar -d "%BIRT_PATH%"

@echo Renaming axis.jar to axis.jar.backup
rename %TARGET_PATH%\axis.jar axis.jar.backup


@echo Renaming org.apache.xml.serializer.jar to org.apache.xml.serializer.jar.backup
set NEWEST_FILE=
call :getNewest %TARGET_PATH%\org.apache.xml.serializer_*.jar
if not (%NEWEST_FILE%)==() rename %TARGET_PATH%\%NEWEST_FILE% %NEWEST_FILE%.backup
goto:eof

rem Set variable NEWEST_FILE to the newest version of the passed plugin
:getNewest
FOR /F "delims=" %%I IN ('DIR %1 /B /O:-D') DO set "NEWEST_FILE=%%I"
goto :eof


endlocal
